@@ -8,6 +8,7 @@ import (
 	"path/filepath"
 	"strconv"
 	"strings"
+	"unicode"
 
 	"github.com/AlecAivazis/survey/v2"
 	"github.com/crowdsecurity/crowdsec/pkg/metabase"
@@ -27,7 +28,7 @@ var (
 	/**/
 	metabaseListenAddress = "127.0.0.1"
 	metabaseListenPort    = "3000"
-	metabaseContainerID   = "/crowdsec-metabase"
+	metabaseContainerID   = "crowdsec-metabase"
 	crowdsecGroup         = "crowdsec"
 
 	forceYes bool
@@ -40,9 +41,12 @@ func NewDashboardCmd() *cobra.Command {
 	/* ---- UPDATE COMMAND */
 	var cmdDashboard = &cobra.Command{
 		Use:   "dashboard [command]",
-		Short: "Manage your metabase dashboard container",
-		Long:  `Install/Start/Stop/Remove a metabase container exposing dashboard and metrics.`,
-		Args:  cobra.ExactArgs(1),
+		Short: "Manage your metabase dashboard container [requires local API]",
+		Long: `Install/Start/Stop/Remove a metabase container exposing dashboard and metrics.
+Note: This command requires database direct access, so is intended to be run on Local API/master.
+		`,
+		Args:              cobra.ExactArgs(1),
+		DisableAutoGenTag: true,
 		Example: `
 cscli dashboard setup
 cscli dashboard start
@@ -50,20 +54,45 @@ cscli dashboard stop
 cscli dashboard remove
 `,
 		PersistentPreRun: func(cmd *cobra.Command, args []string) {
+			if err := metabase.TestAvailability(); err != nil {
+				log.Fatalf("%s", err)
+			}
+
+			if err := csConfig.LoadAPIServer(); err != nil || csConfig.DisableAPI {
+				log.Fatal("Local API is disabled, please run this command on the local API machine")
+			}
+
 			metabaseConfigFolderPath := filepath.Join(csConfig.ConfigPaths.ConfigDir, metabaseConfigFolder)
 			metabaseConfigPath = filepath.Join(metabaseConfigFolderPath, metabaseConfigFile)
 			if err := os.MkdirAll(metabaseConfigFolderPath, os.ModePerm); err != nil {
 				log.Fatalf(err.Error())
 			}
+			if err := csConfig.LoadDBConfig(); err != nil {
+				log.Errorf("This command requires direct database access (must be run on the local API machine)")
+				log.Fatalf(err.Error())
+			}
+
+			/*
+				Old container name was "/crowdsec-metabase" but podman doesn't
+				allow '/' in container name. We do this check to not break
+				existing dashboard setup.
+			*/
+			if !metabase.IsContainerExist(metabaseContainerID) {
+				oldContainerID := fmt.Sprintf("/%s", metabaseContainerID)
+				if metabase.IsContainerExist(oldContainerID) {
+					metabaseContainerID = oldContainerID
+				}
+			}
 		},
 	}
 
 	var force bool
 	var cmdDashSetup = &cobra.Command{
-		Use:   "setup",
-		Short: "Setup a metabase container.",
-		Long:  `Perform a metabase docker setup, download standard dashboards, create a fresh user and start the container`,
-		Args:  cobra.ExactArgs(0),
+		Use:               "setup",
+		Short:             "Setup a metabase container.",
+		Long:              `Perform a metabase docker setup, download standard dashboards, create a fresh user and start the container`,
+		Args:              cobra.ExactArgs(0),
+		DisableAutoGenTag: true,
 		Example: `
 cscli dashboard setup
 cscli dashboard setup --listen 0.0.0.0
@@ -75,7 +104,11 @@ cscli dashboard setup -l 0.0.0.0 -p 443 --password <password>
 			}
 
 			if metabasePassword == "" {
-				metabasePassword = generatePassword(16)
+				isValid := passwordIsValid(metabasePassword)
+				for !isValid {
+					metabasePassword = generatePassword(16)
+					isValid = passwordIsValid(metabasePassword)
+				}
 			}
 			var answer bool
 			groupExist := false
@@ -118,7 +151,7 @@ cscli dashboard setup -l 0.0.0.0 -p 443 --password <password>
 				log.Fatalf("unable to chown sqlite db file '%s': %s", csConfig.DbConfig.DbPath, err)
 			}
 
-			mb, err := metabase.SetupMetabase(csConfig.API.Server.DbConfig, metabaseListenAddress, metabaseListenPort, metabaseUser, metabasePassword, metabaseDbPath, dockerGroup.Gid)
+			mb, err := metabase.SetupMetabase(csConfig.API.Server.DbConfig, metabaseListenAddress, metabaseListenPort, metabaseUser, metabasePassword, metabaseDbPath, dockerGroup.Gid, metabaseContainerID)
 			if err != nil {
 				log.Fatalf(err.Error())
 			}
@@ -145,12 +178,13 @@ cscli dashboard setup -l 0.0.0.0 -p 443 --password <password>
 	cmdDashboard.AddCommand(cmdDashSetup)
 
 	var cmdDashStart = &cobra.Command{
-		Use:   "start",
-		Short: "Start the metabase container.",
-		Long:  `Stats the metabase container using docker.`,
-		Args:  cobra.ExactArgs(0),
+		Use:               "start",
+		Short:             "Start the metabase container.",
+		Long:              `Stats the metabase container using docker.`,
+		Args:              cobra.ExactArgs(0),
+		DisableAutoGenTag: true,
 		Run: func(cmd *cobra.Command, args []string) {
-			mb, err := metabase.NewMetabase(metabaseConfigPath)
+			mb, err := metabase.NewMetabase(metabaseConfigPath, metabaseContainerID)
 			if err != nil {
 				log.Fatalf(err.Error())
 			}
@@ -164,10 +198,11 @@ cscli dashboard setup -l 0.0.0.0 -p 443 --password <password>
 	cmdDashboard.AddCommand(cmdDashStart)
 
 	var cmdDashStop = &cobra.Command{
-		Use:   "stop",
-		Short: "Stops the metabase container.",
-		Long:  `Stops the metabase container using docker.`,
-		Args:  cobra.ExactArgs(0),
+		Use:               "stop",
+		Short:             "Stops the metabase container.",
+		Long:              `Stops the metabase container using docker.`,
+		Args:              cobra.ExactArgs(0),
+		DisableAutoGenTag: true,
 		Run: func(cmd *cobra.Command, args []string) {
 			if err := metabase.StopContainer(metabaseContainerID); err != nil {
 				log.Fatalf("unable to stop container '%s': %s", metabaseContainerID, err)
@@ -177,10 +212,11 @@ cscli dashboard setup -l 0.0.0.0 -p 443 --password <password>
 	cmdDashboard.AddCommand(cmdDashStop)
 
 	var cmdDashRemove = &cobra.Command{
-		Use:   "remove",
-		Short: "removes the metabase container.",
-		Long:  `removes the metabase container using docker.`,
-		Args:  cobra.ExactArgs(0),
+		Use:               "remove",
+		Short:             "removes the metabase container.",
+		Long:              `removes the metabase container using docker.`,
+		Args:              cobra.ExactArgs(0),
+		DisableAutoGenTag: true,
 		Example: `
 cscli dashboard remove
 cscli dashboard remove --force
@@ -240,3 +276,19 @@ cscli dashboard remove --force
 
 	return cmdDashboard
 }
+
+func passwordIsValid(password string) bool {
+	hasDigit := false
+	for _, j := range password {
+		if unicode.IsDigit(j) {
+			hasDigit = true
+			break
+		}
+	}
+
+	if !hasDigit || len(password) < 6 {
+		return false
+	}
+	return true
+
+}
