@@ -256,7 +256,7 @@ cscli machines add MyTestMachine --password MyPassword
 			if err != nil {
 				log.Fatalf("unable to marshal api credentials: %s", err)
 			}
-			if dumpFile != "" {
+			if dumpFile != "" && dumpFile != "-" {
 				err = ioutil.WriteFile(dumpFile, apiConfigDump, 0644)
 				if err != nil {
 					log.Fatalf("write api credentials in '%s' failed: %s", dumpFile, err)
