@@ -1,6 +1,11 @@
 package main
 
 import (
+	"fmt"
+	"path"
+	"path/filepath"
+	"strings"
+
 	"github.com/crowdsecurity/crowdsec/pkg/csconfig"
 	"github.com/crowdsecurity/crowdsec/pkg/cwhub"
 	"github.com/crowdsecurity/crowdsec/pkg/cwversion"
@@ -14,7 +19,7 @@ import (
 var trace_lvl, dbg_lvl, nfo_lvl, wrn_lvl, err_lvl bool
 
 var ConfigFilePath string
-var csConfig *csconfig.GlobalConfig
+var csConfig *csconfig.Config
 var dbClient *database.Client
 
 var OutputFormat string
@@ -28,7 +33,7 @@ var restoreOldBackup bool
 var prometheusURL string
 
 func initConfig() {
-
+	var err error
 	if trace_lvl {
 		log.SetLevel(log.TraceLevel)
 	} else if dbg_lvl {
@@ -42,12 +47,15 @@ func initConfig() {
 	}
 	logFormatter := &log.TextFormatter{TimestampFormat: "02-01-2006 03:04:05 PM", FullTimestamp: true}
 	log.SetFormatter(logFormatter)
-	csConfig = csconfig.NewConfig()
-
-	log.Debugf("Using %s as configuration file", ConfigFilePath)
-	if err := csConfig.LoadConfigurationFile(ConfigFilePath, csConfig.DisableAPI, csConfig.DisableAgent); err != nil {
+	csConfig, err = csconfig.NewConfig(ConfigFilePath, false, false)
+	if err != nil {
 		log.Fatalf(err.Error())
 	}
+	log.Debugf("Using %s as configuration file", ConfigFilePath)
+	if err := csConfig.LoadCSCLI(); err != nil {
+		log.Fatalf(err.Error())
+	}
+
 	if csConfig.Cscli == nil {
 		log.Fatalf("missing 'cscli' configuration in '%s', exiting", ConfigFilePath)
 	}
@@ -74,6 +82,27 @@ func initConfig() {
 
 }
 
+var validArgs = []string{
+	"scenarios", "parsers", "collections", "capi", "lapi", "postoverflows", "machines",
+	"metrics", "bouncers", "alerts", "decisions", "simulation", "hub", "dashboard",
+	"config", "completion", "version", "console",
+}
+
+func prepender(filename string) string {
+	const header = `---
+id: %s
+title: %s
+---
+`
+	name := filepath.Base(filename)
+	base := strings.TrimSuffix(name, path.Ext(name))
+	return fmt.Sprintf(header, base, strings.Replace(base, "_", " ", -1))
+}
+
+func linkHandler(name string) string {
+	return fmt.Sprintf("/cscli/%s", name)
+}
+
 func main() {
 
 	var rootCmd = &cobra.Command{
@@ -81,15 +110,18 @@ func main() {
 		Short: "cscli allows you to manage crowdsec",
 		Long: `cscli is the main command to interact with your crowdsec service, scenarios & db.
 It is meant to allow you to manage bans, parsers/scenarios/etc, api and generally manage you crowdsec setup.`,
+		ValidArgs:         validArgs,
+		DisableAutoGenTag: true,
 		/*TBD examples*/
 	}
 	var cmdDocGen = &cobra.Command{
-		Use:    "doc",
-		Short:  "Generate the documentation in `./doc/`. Directory must exist.",
-		Args:   cobra.ExactArgs(0),
-		Hidden: true,
+		Use:               "doc",
+		Short:             "Generate the documentation in `./doc/`. Directory must exist.",
+		Args:              cobra.ExactArgs(0),
+		Hidden:            true,
+		DisableAutoGenTag: true,
 		Run: func(cmd *cobra.Command, args []string) {
-			if err := doc.GenMarkdownTree(rootCmd, "./doc/"); err != nil {
+			if err := doc.GenMarkdownTreeCustom(rootCmd, "./doc/", prepender, linkHandler); err != nil {
 				log.Fatalf("Failed to generate cobra doc: %s", err.Error())
 			}
 		},
@@ -97,10 +129,10 @@ It is meant to allow you to manage bans, parsers/scenarios/etc, api and generall
 	rootCmd.AddCommand(cmdDocGen)
 	/*usage*/
 	var cmdVersion = &cobra.Command{
-		Use:    "version",
-		Short:  "Display version and exit.",
-		Args:   cobra.ExactArgs(0),
-		Hidden: true,
+		Use:               "version",
+		Short:             "Display version and exit.",
+		Args:              cobra.ExactArgs(0),
+		DisableAutoGenTag: true,
 		Run: func(cmd *cobra.Command, args []string) {
 			cwversion.Show()
 		},
@@ -140,6 +172,10 @@ It is meant to allow you to manage bans, parsers/scenarios/etc, api and generall
 	rootCmd.AddCommand(NewPostOverflowsCmd())
 	rootCmd.AddCommand(NewCapiCmd())
 	rootCmd.AddCommand(NewLapiCmd())
+	rootCmd.AddCommand(NewCompletionCmd())
+	rootCmd.AddCommand(NewConsoleCmd())
+	rootCmd.AddCommand(NewExplainCmd())
+	rootCmd.AddCommand(NewHubTestCmd())
 	if err := rootCmd.Execute(); err != nil {
 		log.Fatalf("While executing root command : %s", err)
 	}
