@@ -10,12 +10,16 @@ import (
 
 /*daemonization/service related stuff*/
 type CommonCfg struct {
-	Daemonize  bool
-	PidDir     string     `yaml:"pid_dir"`
-	LogMedia   string     `yaml:"log_media"`
-	LogDir     string     `yaml:"log_dir,omitempty"` //if LogMedia = file
-	LogLevel   *log.Level `yaml:"log_level"`
-	WorkingDir string     `yaml:"working_dir,omitempty"` ///var/run
+	Daemonize    bool
+	PidDir       string     `yaml:"pid_dir"`
+	LogMedia     string     `yaml:"log_media"`
+	LogDir       string     `yaml:"log_dir,omitempty"` //if LogMedia = file
+	LogLevel     *log.Level `yaml:"log_level"`
+	WorkingDir   string     `yaml:"working_dir,omitempty"` ///var/run
+	CompressLogs *bool      `yaml:"compress_logs,omitempty"`
+	LogMaxSize   int        `yaml:"log_max_size,omitempty"`
+	LogMaxAge    int        `yaml:"log_max_age,omitempty"`
+	LogMaxFiles  int        `yaml:"log_max_files,omitempty"`
 }
 
 func (c *Config) LoadCommon() error {
