@@ -8,6 +8,7 @@ import (
 	"sort"
 
 	"github.com/pkg/errors"
+	"golang.org/x/mod/semver"
 
 	//"log"
 
@@ -49,7 +50,7 @@ func parser_visit(path string, f os.FileInfo, err error) error {
 	subs := strings.Split(path, "/")
 
 	log.Tracef("path:%s, hubdir:%s, installdir:%s", path, hubdir, installdir)
-	/*we're in hub (~/.cscli/hub/)*/
+	/*we're in hub (~/.hub/hub/)*/
 	if strings.HasPrefix(path, hubdir) {
 		log.Tracef("in hub dir")
 		inhub = true
@@ -80,6 +81,7 @@ func parser_visit(path string, f os.FileInfo, err error) error {
 		return fmt.Errorf("File '%s' is not from hub '%s' nor from the configuration directory '%s'", path, hubdir, installdir)
 	}
 
+	log.Tracef("stage:%s ftype:%s", stage, ftype)
 	//log.Printf("%s -> name:%s stage:%s", path, fname, stage)
 	if stage == SCENARIOS {
 		ftype = SCENARIOS
@@ -95,20 +97,19 @@ func parser_visit(path string, f os.FileInfo, err error) error {
 
 	/*
 		we can encounter 'collections' in the form of a symlink :
-		/etc/crowdsec/.../collections/linux.yaml -> ~/.cscli/hub/collections/.../linux.yaml
+		/etc/crowdsec/.../collections/linux.yaml -> ~/.hub/hub/collections/.../linux.yaml
 		when the collection is installed, both files are created
 	*/
 	//non symlinks are local user files or hub files
 	if f.Mode()&os.ModeSymlink == 0 {
 		local = true
-		skippedLocal++
 		log.Tracef("%s isn't a symlink", path)
 	} else {
 		hubpath, err = os.Readlink(path)
 		if err != nil {
 			return fmt.Errorf("unable to read symlink of %s", path)
 		}
-		//the symlink target doesn't exist, user might have remove ~/.cscli/hub/...yaml without deleting /etc/crowdsec/....yaml
+		//the symlink target doesn't exist, user might have removed ~/.hub/hub/...yaml without deleting /etc/crowdsec/....yaml
 		_, err := os.Lstat(hubpath)
 		if os.IsNotExist(err) {
 			log.Infof("%s is a symlink to %s that doesn't exist, deleting symlink", path, hubpath)
@@ -243,6 +244,12 @@ func parser_visit(path string, f os.FileInfo, err error) error {
 }
 
 func CollecDepsCheck(v *Item) error {
+
+	if GetVersionStatus(v) != 0 { //not up-to-date
+		log.Debugf("%s dependencies not checked : not up-to-date", v.Name)
+		return nil
+	}
+
 	/*if it's a collection, ensure all the items are installed, or tag it as tainted*/
 	if v.Type == COLLECTIONS {
 		log.Tracef("checking submembers of %s installed:%t", v.Name, v.Installed)
@@ -294,10 +301,11 @@ func CollecDepsCheck(v *Item) error {
 	return nil
 }
 
-func SyncDir(cscli *csconfig.CscliCfg, dir string) error {
-	hubdir = cscli.HubDir
-	installdir = cscli.ConfigDir
-	indexpath = cscli.HubIndexFile
+func SyncDir(hub *csconfig.Hub, dir string) (error, []string) {
+	hubdir = hub.HubDir
+	installdir = hub.ConfigDir
+	indexpath = hub.HubIndexFile
+	warnings := []string{}
 
 	/*For each, scan PARSERS, PARSERS_OVFLW, SCENARIOS and COLLECTIONS last*/
 	for _, scan := range ItemTypes {
@@ -307,41 +315,52 @@ func SyncDir(cscli *csconfig.CscliCfg, dir string) error {
 		}
 		err = filepath.Walk(cpath, parser_visit)
 		if err != nil {
-			return err
+			return err, warnings
 		}
 
 	}
 
 	for k, v := range hubIdx[COLLECTIONS] {
-		if err := CollecDepsCheck(&v); err != nil {
-			log.Infof("dependency issue %s : %s", v.Name, err)
+		if v.Installed {
+			versStat := GetVersionStatus(&v)
+			if versStat == 0 { //latest
+				if err := CollecDepsCheck(&v); err != nil {
+					warnings = append(warnings, fmt.Sprintf("dependency of %s : %s", v.Name, err))
+					hubIdx[COLLECTIONS][k] = v
+				}
+			} else if versStat == 1 { //not up-to-date
+				warnings = append(warnings, fmt.Sprintf("update for collection %s available (currently:%s, latest:%s)", v.Name, v.LocalVersion, v.Version))
+			} else { //version is higher than the highest available from hub?
+				warnings = append(warnings, fmt.Sprintf("collection %s is in the future (currently:%s, latest:%s)", v.Name, v.LocalVersion, v.Version))
+			}
+			log.Debugf("installed (%s) - status:%d | installed:%s | latest : %s | full : %+v", v.Name, semver.Compare("v"+v.Version, "v"+v.LocalVersion), v.LocalVersion, v.Version, v.Versions)
 		}
-		hubIdx[COLLECTIONS][k] = v
 	}
-	return nil
+	return nil, warnings
 }
 
 /* Updates the infos from HubInit() with the local state */
-func LocalSync(cscli *csconfig.CscliCfg) error {
+func LocalSync(hub *csconfig.Hub) (error, []string) {
 	skippedLocal = 0
 	skippedTainted = 0
 
-	for _, dir := range []string{cscli.ConfigDir, cscli.HubDir} {
-		log.Debugf("scanning %s", dir)
-		if err := SyncDir(cscli, dir); err != nil {
-			return fmt.Errorf("failed to scan %s : %s", dir, err)
-		}
+	err, warnings := SyncDir(hub, hub.ConfigDir)
+	if err != nil {
+		return fmt.Errorf("failed to scan %s : %s", hub.ConfigDir, err), warnings
 	}
-
-	return nil
+	err, _ = SyncDir(hub, hub.HubDir)
+	if err != nil {
+		return fmt.Errorf("failed to scan %s : %s", hub.HubDir, err), warnings
+	}
+	return nil, warnings
 }
 
-func GetHubIdx(cscli *csconfig.CscliCfg) error {
-	if cscli == nil {
-		return fmt.Errorf("no configuration found for cscli")
+func GetHubIdx(hub *csconfig.Hub) error {
+	if hub == nil {
+		return fmt.Errorf("no configuration found for hub")
 	}
-	log.Debugf("loading hub idx %s", cscli.HubIndexFile)
-	bidx, err := ioutil.ReadFile(cscli.HubIndexFile)
+	log.Debugf("loading hub idx %s", hub.HubIndexFile)
+	bidx, err := ioutil.ReadFile(hub.HubIndexFile)
 	if err != nil {
 		return errors.Wrap(err, "unable to read index file")
 	}
@@ -353,7 +372,8 @@ func GetHubIdx(cscli *csconfig.CscliCfg) error {
 		return err
 	}
 	hubIdx = ret
-	if err := LocalSync(cscli); err != nil {
+	err, _ = LocalSync(hub)
+	if err != nil {
 		log.Fatalf("Failed to sync Hub index with local deployment : %v", err)
 	}
 	return nil
