@@ -142,7 +142,7 @@ func (c *Client) UpdateCommunityBlocklist(alertItem *models.Alert) (int, int, in
 	ts, err := time.Parse(time.RFC3339, *alertItem.StopAt)
 	if err != nil {
 		c.Log.Errorf("While parsing StartAt of item %s : %s", *alertItem.StopAt, err)
-		ts = time.Now()
+		ts = time.Now().UTC()
 	}
 
 	alertB := c.Ent.Alert.
@@ -409,7 +409,7 @@ func (c *Client) CreateAlertBulk(machineId string, alertList []*models.Alert) ([
 		ts, err := time.Parse(time.RFC3339, *alertItem.StopAt)
 		if err != nil {
 			c.Log.Errorf("While parsing StartAt of item %s : %s", *alertItem.StopAt, err)
-			ts = time.Now()
+			ts = time.Now().UTC()
 		}
 
 		decisions = make([]*ent.Decision, 0)
@@ -561,6 +561,10 @@ func BuildAlertRequestFromFilter(alerts *ent.AlertQuery, filter map[string][]str
 		delete(filter, "simulated")
 	}
 
+	if _, ok := filter["origin"]; ok {
+		filter["include_capi"] = []string{"true"}
+	}
+
 	for param, value := range filter {
 		switch param {
 		case "contains":
@@ -579,7 +583,7 @@ func BuildAlertRequestFromFilter(alerts *ent.AlertQuery, filter map[string][]str
 		case "value":
 			alerts = alerts.Where(alert.SourceValueEQ(value[0]))
 		case "scenario":
-			alerts = alerts.Where(alert.ScenarioEQ(value[0]))
+			alerts = alerts.Where(alert.HasDecisionsWith(decision.ScenarioEQ(value[0])))
 		case "ip", "range":
 			ip_sz, start_ip, start_sfx, end_ip, end_sfx, err = types.Addr2Ints(value[0])
 			if err != nil {
@@ -590,7 +594,7 @@ func BuildAlertRequestFromFilter(alerts *ent.AlertQuery, filter map[string][]str
 			if err != nil {
 				return nil, errors.Wrap(err, "while parsing duration")
 			}
-			since := time.Now().Add(-duration)
+			since := time.Now().UTC().Add(-duration)
 			if since.IsZero() {
 				return nil, fmt.Errorf("Empty time now() - %s", since.String())
 			}
@@ -600,7 +604,7 @@ func BuildAlertRequestFromFilter(alerts *ent.AlertQuery, filter map[string][]str
 			if err != nil {
 				return nil, errors.Wrap(err, "while parsing duration")
 			}
-			since := time.Now().Add(-duration)
+			since := time.Now().UTC().Add(-duration)
 			if since.IsZero() {
 				return nil, fmt.Errorf("Empty time now() - %s", since.String())
 			}
@@ -610,16 +614,18 @@ func BuildAlertRequestFromFilter(alerts *ent.AlertQuery, filter map[string][]str
 			if err != nil {
 				return nil, errors.Wrap(err, "while parsing duration")
 			}
-			until := time.Now().Add(-duration)
+			until := time.Now().UTC().Add(-duration)
 			if until.IsZero() {
 				return nil, fmt.Errorf("Empty time now() - %s", until.String())
 			}
 			alerts = alerts.Where(alert.StartedAtLTE(until))
 		case "decision_type":
 			alerts = alerts.Where(alert.HasDecisionsWith(decision.TypeEQ(value[0])))
+		case "origin":
+			alerts = alerts.Where(alert.HasDecisionsWith(decision.OriginEQ(value[0])))
 		case "include_capi": //allows to exclude one or more specific origins
 			if value[0] == "false" {
-				alerts = alerts.Where(alert.HasDecisionsWith(decision.OriginNEQ(CapiMachineID)))
+				alerts = alerts.Where(alert.HasDecisionsWith(decision.Or(decision.OriginEQ("crowdsec"), decision.OriginEQ("cscli"))))
 			} else if value[0] != "true" {
 				log.Errorf("Invalid bool '%s' for include_capi", value[0])
 			}
@@ -628,7 +634,7 @@ func BuildAlertRequestFromFilter(alerts *ent.AlertQuery, filter map[string][]str
 				return nil, errors.Wrapf(ParseType, "'%s' is not a boolean: %s", value[0], err)
 			}
 			if hasActiveDecision {
-				alerts = alerts.Where(alert.HasDecisionsWith(decision.UntilGTE(time.Now())))
+				alerts = alerts.Where(alert.HasDecisionsWith(decision.UntilGTE(time.Now().UTC())))
 			} else {
 				alerts = alerts.Where(alert.Not(alert.HasDecisions()))
 			}
@@ -747,17 +753,20 @@ func (c *Client) QueryAlertWithFilter(filter map[string][]string) ([]*ent.Alert,
 			WithEvents().
 			WithMetas().
 			WithOwner()
-		if sort == "ASC" {
-			alerts = alerts.Order(ent.Asc(alert.FieldCreatedAt))
-		} else {
-			alerts = alerts.Order(ent.Desc(alert.FieldCreatedAt))
-		}
+
 		if limit == 0 {
 			limit, err = alerts.Count(c.CTX)
 			if err != nil {
 				return []*ent.Alert{}, fmt.Errorf("unable to count nb alerts: %s", err)
 			}
 		}
+
+		if sort == "ASC" {
+			alerts = alerts.Order(ent.Asc(alert.FieldCreatedAt))
+		} else {
+			alerts = alerts.Order(ent.Desc(alert.FieldCreatedAt))
+		}
+
 		result, err := alerts.Limit(paginationSize).Offset(offset).All(c.CTX)
 		if err != nil {
 			return []*ent.Alert{}, errors.Wrapf(QueryFail, "pagination size: %d, offset: %d: %s", paginationSize, offset, err)
@@ -865,7 +874,7 @@ func (c *Client) FlushOrphans() {
 	}
 
 	events_count, err = c.Ent.Decision.Delete().Where(
-		decision.Not(decision.HasOwner())).Where(decision.UntilLTE(time.Now())).Exec(c.CTX)
+		decision.Not(decision.HasOwner())).Where(decision.UntilLTE(time.Now().UTC())).Exec(c.CTX)
 
 	if err != nil {
 		c.Log.Warningf("error while deleting orphan decisions : %s", err)
