@@ -1,10 +1,9 @@
 package schema
 
 import (
-	"time"
-
-	"github.com/facebook/ent"
-	"github.com/facebook/ent/schema/field"
+	"entgo.io/ent"
+	"entgo.io/ent/schema/field"
+	"github.com/crowdsecurity/crowdsec/pkg/types"
 )
 
 // Bouncer holds the schema definition for the Bouncer entity.
@@ -16,18 +15,20 @@ type Bouncer struct {
 func (Bouncer) Fields() []ent.Field {
 	return []ent.Field{
 		field.Time("created_at").
-			Default(time.Now),
+			Default(types.UtcNow).
+			UpdateDefault(types.UtcNow).Nillable().Optional(),
 		field.Time("updated_at").
-			Default(time.Now),
+			Default(types.UtcNow).
+			UpdateDefault(types.UtcNow).Nillable().Optional(),
 		field.String("name").Unique(),
 		field.String("api_key"), // hash of api_key
 		field.Bool("revoked"),
 		field.String("ip_address").Default("").Optional(),
 		field.String("type").Optional(),
 		field.String("version").Optional(),
-		field.Time("until").Default(time.Now).Optional(),
+		field.Time("until").Default(types.UtcNow).Optional(),
 		field.Time("last_pull").
-			Default(time.Now),
+			Default(types.UtcNow),
 	}
 }
 
